@@ -881,7 +881,7 @@ sub build_lvm_commands {
     # prevent error due to different VG name of existing VG
     if (defined($FAI::configs{$d})) {
       # don't deactivate preserved VGs to prevent blkid error later on
-      foreach my $v (keys %{ $FAI::configs->{$d}->{volumes} }) {
+      foreach my $v (keys %{ $FAI::configs{$d}->{volumes} }) {
         $preserved = 1 if ($FAI::configs{$d}{volumes}{$v}{size}{preserve});
       }
     }
